#Required packages
library(tidyverse)
library(dplyr)
library(cowplot)
library(brms)
library(modelr)
library(tidybayes)
library(tidyverse)

##############################################
# Hatching Pattern

### Plot the mean proportion embryos that hatched during each 8hr observation interval by treatment and time observed
# Load Data: MeanProportionHatched.csv
# insert file path
prop.hatched <- read.csv("MeanProportionHatched.csv")
#-or-
# select file manually
#morph <- read.csv(file.choose(), header = TRUE)

## Data for plotting light and dark photo periods by time observed
photoperiod <- read.csv("photoperiod.csv")

## Labels for figure
Time_names <- c(`6` = "06:00",
                `14` = "14:00",
                `22` = "22:00")
## Plot data
plot <- ggplot() + 
  geom_rect(data=photoperiod %>% filter(AgeHPF >= 48, AgeHPF <= 256), 
            (aes(xmin=AgeHPF,xmax=AgeHPF+1, ymin=0, ymax=1, fill=factor(Light))), alpha = 0.5, guide = "none")+
  scale_fill_manual(values=c("lightgrey", "white", pal), labels = c("Dark", "Light")) +
  geom_line(data = prop.hatched, aes(x = Age, y = mean_prop_total, group = Treatment, color = Treatment), size = 0.6) +
  scale_color_manual(values=pal, labels = c("ES", "NS", "PS")) +
  facet_grid(factor(Time_observed)~., labeller = as_labeller(Time_names)) +
  scale_x_continuous(breaks=seq(48,256,8),   
                     expand = expansion(mult = c(0, 0))) +
  scale_y_continuous(breaks=seq(0,1,.20), expand = expansion(mult = c(0, 0))) +
  ylab("Mean proportion of clutch hatched") +
  xlab("Hours post-fertilization (HPF)")+
  labs(color = "Treatment:", fill = "Light cycle:") +
  theme_cowplot(10) +
  guides(color = guide_legend(override.aes = list(size = 1.2)), # increases line thickness in legend
         fill = guide_legend(override.aes = list(linetype = "solid", color = "black", size = 0.2)))+ #adds box around light and dark in legend
  theme(axis.text.x = element_text(angle=90), #rotates text 90degrees
        axis.title.y = element_text(margin = margin(t = 0, r = 5, b = 0, l = 0)), #Move y-axis label away from axes
        axis.title.x = element_text(margin = margin(t = 5, r = 0, b = 0, l = 0)),
        panel.spacing = unit(1, "lines"),
        legend.text = element_text(size = 8),
        legend.title = element_text(size = 8),
        legend.box.background = element_rect(fill = "white", linetype = 0),
        legend.box = "vertical",
        legend.margin =margin(r=2,l=2,t=2,b=2),
        legend.justification = c(1.03, 1.05), 
        legend.position = c(1, 1),
        legend.box.margin=margin(c(1,1,1,1)))
plot


##############################################
### BAYSIAN MODELS to compare hatching age, duration, and success among treatments and time observed
##############################################

## AGE
# LOAD DATA: age.csv
age <- read.csv("age.csv") %>%
  mutate(Treatment = case_when(Treatment == "MIH" ~ "ES", 
                               Treatment == "NIH" ~ "NS",
                               TRUE ~ "PS"))
# model formula for age
## Long Run Time ##
age.mod <- brm(Age ~ Treatment + as.factor(Time_observed) + (1|PairID), data = age, family = "negbinomial", iter = 5000) # no interaction model
summary(age.mod)

age.mod.2 <- brm(Age ~ Treatment * as.factor(Time_observed) + (1|PairID), data = age, family = "negbinomial", iter = 5000) # interaction model
summary(age.mod.2)

# test LOOIC
loo(age.mod, age.mod.2) 
# interaction model is clearly better

# get effect sizes and intervals for in text reporting
q2 <- c(q2 = "Treatment +  Treatment:Time_observed = 0")
psamps <- as.data.frame(posterior_samples(age.mod.2, '^b')) %>%
  mutate(singleNS = b_Intercept + b_TreatmentNS,
         singlePS = b_Intercept + b_TreatmentPS,
         single14 = b_Intercept + b_as.factorTime_observed14,
         single22 = b_Intercept + b_as.factorTime_observed22,
         intNS14 = b_Intercept + `b_TreatmentNS:as.factorTime_observed14`,
         intPS14 = b_Intercept + `b_TreatmentPS:as.factorTime_observed14`,
         intNS22 = b_Intercept + `b_TreatmentNS:as.factorTime_observed22`,
         intPS22 = b_Intercept + `b_TreatmentPS:as.factorTime_observed22`) %>%
  select(c(1,10:17))

# gather data into long format
psamps.long <- psamps %>%
  gather(key = int, value = param)

# summarize and get intervals of posterior parameters
psamps.sum <- as.data.frame(psamps.long) %>%
  group_by(int) %>%
  summarise(value = list(enframe(quantile(param, probs=c(0.025,0.5,0.975))))) %>%
  unnest() %>%
  mutate(x = exp(value))

# also get priobabilities of effects for in text reporting
psamps.prop <- posterior_samples(age.mod.2, '^b') %>%
  # mutate(b_treatment_groupT = b_Intercept + b_treatment_groupT) %>% 
  pivot_longer(everything(),
               names_to = 'intercept',
               values_to = 'post_value') %>% 
  mutate(direction = case_when(post_value >= 0 ~ 'positive',
                               TRUE ~ 'negative')) %>% 
  group_by(intercept, direction) %>% 
  summarise(prop = (n()/10000) * 100)


# get model predictions
age.pred <- age %>%
  data_grid(Treatment, 
            Time_observed, 
            PairID = NA) %>%
  add_fitted_draws(age.mod.2, n = 500) 

# plot data
age.pred.plot <- ggplot() + 
  geom_violin(data = age.pred, aes(x = Treatment, y = .value, fill = as.factor(Treatment), 
                                   alpha = interaction(Treatment, as.factor(Time_observed))), trim = T, 
              draw_quantiles = c(0.025, 0.5, 0.975), 
              position = position_dodge(width = 0.75), size = 0.4) +
  scale_shape_manual(values = c(21,21,21), labels = c("06:00", "14:00", "22:00")) +
  scale_fill_manual(values = alpha(pal, 0.1)) +
  scale_color_manual(values = alpha(c("black", "black", "black"), 0.5)) +
  scale_alpha_manual(values=rep(c(0.4,0.6,0.8), each=3)) +
  geom_point(data = age, aes(x = Treatment, y = Age, fill = as.factor(Treatment), shape = as.factor(Time_observed), color = as.factor(Treatment),
                             group = as.factor(Time_observed), alpha = interaction(Treatment, as.factor(Time_observed))), 
             position = position_jitterdodge(), 
             size = 1, 
             stroke = 0.2) +
  scale_y_continuous(breaks=seq(80,240,20)) +
  ylab("Age at hatch (hpf)") +
  labs(fill = "Treatment:", shape = "Time Observed:") +
  guides(shape = guide_legend(order = 2, override.aes = list(size = 3,stroke = 0.7, alpha = 1)),
         #fill = guide_legend(order = 1, override.aes = list(shape = "", alpha = 1)),
         fill = "none",
         alpha = "none",
         color = "none")+ #adds box around light and dark in legend
  theme_cowplot(10) +
  theme(legend.direction = "horizontal",
        legend.position = c(0.5,0.99), 
        legend.justification = c(0.5,0.5),
        legend.text = element_text(size = 8),
        legend.title = element_text(size = 8)) +
  xlab("")
age.pred.plot

##############################################
## HATCHING DURATION

#LOAD DATA: duration.csv
duration <- read.csv("duration.csv") %>%
  mutate(dur.mins = case_when(duration > 10 ~ duration*60,
                              duration < 10 ~ round(duration*60))) %>% #transforming to minutes 
  mutate(Treatment = case_when(Treatment == "MIH" ~ "ES", 
                               Treatment == "NIH" ~ "NS",
                               TRUE ~ "PS")) # adjusting labeling

# same as above, with negative binomial error dist
## Long Run Time ##
duration.mod <- brm(dur.mins ~ Treatment + as.factor(Time_observed) + (1|PairID), data = duration, family = "negbinomial", iter = 5000)
summary(duration.mod)

duration.mod.2 <- brm(dur.mins ~ Treatment * as.factor(Time_observed) + (1|PairID), data = duration, family = "negbinomial", iter = 5000)
summary(duration.mod.2)

loo(duration.mod, duration.mod.2)

psamps <- as.data.frame(posterior_samples(duration.mod, '^b')) %>%
  mutate(singleNS = b_Intercept + b_TreatmentNS,
         singlePS = b_Intercept + b_TreatmentPS,
         single14 = b_Intercept + b_as.factorTime_observed14,
         single22 = b_Intercept + b_as.factorTime_observed22) %>%
  select(c(1,6:9))



psamps.long <- psamps %>%
  gather(key = int, value = param)

psamps.sum <- as.data.frame(psamps.long) %>%
  group_by(int) %>%
  summarise(value = list(enframe(quantile(param, probs=c(0.025,0.5,0.975))))) %>%
  unnest() %>%
  mutate(x = exp(value))

psamps.prop <- posterior_samples(duration.mod, '^b') %>%
  # mutate(b_treatment_groupT = b_Intercept + b_treatment_groupT) %>% 
  pivot_longer(everything(),
               names_to = 'intercept',
               values_to = 'post_value') %>% 
  mutate(direction = case_when(post_value >= 0 ~ 'positive',
                               TRUE ~ 'negative')) %>% 
  group_by(intercept, direction) %>% 
  summarise(prop = (n()/10000) * 100)


dur.pred <- duration %>%
  data_grid(Treatment, 
            Time_observed, 
            PairID = NA) %>%
  add_fitted_draws(duration.mod, n = 500)

dur.pred.plot <- ggplot(data = dur.pred, aes(x = Treatment, y = log(.value), fill = as.factor(Treatment))) + 
  geom_violin(trim = T, draw_quantiles = c(0.025, 0.5, 0.975), size = 0.4) +
  scale_fill_manual(values = pal) +
  geom_point(data = duration, aes(x = Treatment, y = log(dur.mins), fill = as.factor(Treatment)), pch = 21, position = position_jitterdodge(), size = 2, stroke = 0.6, alpha = 0.4) +
  ylab("log(Hatching duration (min))") +
  theme_cowplot(10) +
  theme(legend.position = "none") +
  xlab("")
dur.pred.plot

##############################################
## HATCHING SUCCESS

# LOAD DATA: hsuccess.csv
h.success <- read.csv("hsuccess.csv") %>%
  mutate(h.success = case_when(Hatching_success == 1 ~ 0.9999,
                               Hatching_success == 0 ~ 0.0001, # adjusting values to be within distribution, which does not include 0/1
                               TRUE ~ Hatching_success)) %>%
  mutate(Treatment = case_when(Treatment == "MIH" ~ "ES", 
                               Treatment == "NIH" ~ "NS",
                               TRUE ~ "PS"))

# same exact steps as above, but with beta distribution
## Long Run Time ##
success.mod <- brm(h.success ~ Treatment + as.factor(Time_observed) + (1|PairID), data = h.success, family = "beta", iter = 5000)
summary(success.mod)

success.mod.2 <- brm(h.success ~ Treatment * as.factor(Time_observed) + (1|PairID), data = h.success, family = "beta", iter = 5000)
summary(success.mod.2)

loo(success.mod, success.mod.2)

# success.mod is better

psamps <- as.data.frame(posterior_samples(success.mod, '^b')) %>%
  mutate(singleNS = b_Intercept + b_TreatmentNS,
         singlePS = b_Intercept + b_TreatmentPS,
         single14 = b_Intercept + b_as.factorTime_observed14,
         single22 = b_Intercept + b_as.factorTime_observed22) %>%
  select(c(1,6:9))

psamps.long <- psamps %>%
  gather(key = int, value = param)

psamps.sum <- as.data.frame(psamps.long) %>%
  group_by(int) %>%
  summarise(value = list(enframe(quantile(param, probs=c(0.025,0.5,0.975))))) %>%
  unnest() %>%
  mutate(x = boot::inv.logit(value))

psamps.prop <- posterior_samples(success.mod, '^b') %>%
  # mutate(b_treatment_groupT = b_Intercept + b_treatment_groupT) %>% 
  pivot_longer(everything(),
               names_to = 'intercept',
               values_to = 'post_value') %>% 
  mutate(direction = case_when(post_value >= 0 ~ 'positive',
                               TRUE ~ 'negative')) %>% 
  group_by(intercept, direction) %>% 
  summarise(prop = (n()/10000) * 100)


succ.pred <- h.success %>%
  data_grid(Treatment, 
            Time_observed, 
            PairID = NA) %>%
  add_fitted_draws(success.mod, n = 500) %>%
  group_by(Treatment, .draw) %>%
  summarize(.value = mean(.value))

succ.pred.plot <- ggplot(data = succ.pred, aes(x = Treatment, y = .value, fill = Treatment)) + 
  geom_violin(trim = T, draw_quantiles = c(0.025, 0.5, 0.975), size = 0.4) +
  scale_fill_manual(values = pal) +
  geom_point(data = h.success, aes(x = Treatment, y = h.success, fill = Treatment), pch = 21, size = 2, stroke = 0.6, alpha = 0.4) +
  ylab("Proportion hatched") +
  theme_cowplot(10) +
  theme(legend.position = "none") +
  xlab("")
succ.pred.plot

##############################################
## FIGURE
### Combine plots into a single panel figure
v.plots<- plot_grid(age.pred.plot + theme(legend.position="none"),
                     dur.pred.plot + theme(legend.position="none"), 
                     succ.pred.plot + theme(legend.position="none"), 
                     hjust = 0.8, vjust=0.1, align = "hv", rel_heights= c(1, 1, 1), 
                     labels = c("b.","c.","d."), ncol = 1) + 
  theme(plot.margin = unit(c(1,0.1,0.1,1), "lines"))
v.plots


p.plot <- plot_grid(plot, 
                   labels = c("a."), 
                   hjust = 0.8,
                   vjust=0.1, 
                   align = "v",
                   axis = "t",
                   ncol = 1) +
  theme(plot.margin = unit(c(1,0.1,0.1,1), "lines"))
p.plot

plot_grid(p.plot, v.plots , align = "v", rel_widths = c(1.5,1), ncol = 2)
#ggsave(filename = file.path("Figure3_AgeDurationSuccess_Submission.pdf"), height = 6, width = 8.5, units = "in", dpi = 300)



