#Required packages:
library(tidyr)
library(dplyr)
library(cowplot)
library(fishualize)

# For Ordination Analyses
library(FactoMineR)
library(factoextra)
library(vegan)

#Color pallet for figures
pal <- fish(n = 4, option ="Scarus_quoyi", begin = 0.3, end = 0.9) 

############################################
# HATCHLING MORPHOLOGY

# LOAD DATA
### Data file: morphology.csv
# insert file path
morph <- read.csv("morphology.csv")
#-or-
# select file manually
#morph <- read.csv(file.choose(), header = TRUE)

morph[morph == "."] <- NA # replace missing values coded as "." with NA

# summarize data set
summary(morph)
head(morph)

############################################
# Principle Components Analysis and PERMANOVA
## PCA to assess larval morphology among experimental treatments:
#PCA using the FactoMineR package
my.pca<- PCA(morph[,c(6:9)], scale.unit = TRUE, graph = FALSE)
summary(my.pca)

fviz_eig(my.pca, addlabels = TRUE, ylim = c(0, 60))

# Contributions of variables to PC1
pc1 <- fviz_contrib(my.pca, choice = "var", axes = 1)
# Contributions of variables to PC2
pc2 <- fviz_contrib(my.pca, choice = "var", axes = 2)
# Contributions of variables to PC3
pc3 <- fviz_contrib(my.pca, choice = "var", axes = 3)
# Contributions of variables to PC4
pc4 <- fviz_contrib(my.pca, choice = "var", axes = 4)

# Panel plot of variable contributions
plot_grid(pc1,pc2,pc3,pc4)


############################################
## PCA biplot with convex hulls grouped by treatments

# Convex hauls grouped by treatments
PCA.Plot <- fviz_pca_biplot(my.pca,
                            geom.ind = "point", # show points only, no text
                            col.ind = morph$Treatment, # color by trial type
                            col.var = "black",
                            palette = pal,
                            addEllipses = TRUE, # ellipses
                            ellipse.type = "convex", #adds convex hauls
                            ylim = c(-3,3),
                            xlim = c(-5,5),
                            xlab = "PC 1 (56.4%)",
                            ylab = "PC 2 (28%)",
                            legend.title = "Treatment",
                            title = "",
) +
  theme_classic(base_size = 10) +
  theme(legend.justification = c(1, 1), 
        legend.position = c(1, 1), 
        legend.box.margin=margin(c(1,1,1,1)),
        axis.text.x.bottom = element_text(size=10),
        axis.text.y.left = element_text(size=10))
PCA.Plot

############################################
## PCA biplot with convex hulls grouped by time observed

# Convex hauls grouped by time observed
PCA.Plot2 <- fviz_pca_biplot(my.pca,
                             geom.ind = "point", # show points only, no text
                             col.ind = morph$Time_observed, # color by trial type
                             col.var = "black",
                             palette = pal,
                             addEllipses = TRUE, # ellipses
                             ellipse.type = "convex", #adds convex hauls
                             ylim = c(-3,3),
                             xlim = c(-5,5),
                             xlab = "PC 1 (56.4%)",
                             ylab = "PC 2 (28%)",
                             legend.title = "Treatment",
                             title = "",
) +
  theme_classic(base_size = 10) +
  theme(legend.justification = c(1, 1), 
        legend.position = c(1, 1), 
        legend.box.margin=margin(c(1,1,1,1)),
        axis.text.x.bottom = element_text(size=10),
        axis.text.y.left = element_text(size=10))
PCA.Plot2

############################################
## PERMANOVA using adonis from the vegan package
X <- na.omit(morph) #removes 4 rows that contain NAs from the dataset
Y <- X[,c(6:9)] #Selects columns with trait data

perm1 <- adonis(Y ~ X$Treatment, strata = X$PairID, permutation = 9999, method = "euclidean")
perm1

perm2 <- adonis(Y~ X$Treatment*X$Time_observed, strata = X$PairID, permutation = 9999, method = "euclidean")
perm2


## PERMANOVA: pairwise comparisons among treatment groups with bonferroni correction for multiple comparisons
#create a vector for storing p-values
pairwise_p <- numeric()

#Pairwise comparisons ES vs. NS
X1 <- X %>% 
  ungroup() %>% 
  filter(Treatment != "PS")

Y1 <- X1 %>% select(6:9)

perm1 <- adonis(Y1 ~ X1$Treatment*X1$Time_observed, 
                strata = X1$PairID, 
                permutation = 9999, 
                method = "euclidean")

pairwise_p["ES_NS"] <- perm1[["aov.tab"]][["Pr(>F)"]][1]

#Pairwise comparisons ES vs. PS
X1 <- X %>% 
  ungroup() %>% 
  filter(Treatment != "NS")

Y1 <- X1 %>% select(6:9)

perm1 <- adonis(Y1 ~ X1$Treatment*X1$Time_observed, 
                strata = X1$PairID, 
                permutation = 9999, 
                method = "euclidean")

pairwise_p["ES_PS"] <- perm1[["aov.tab"]][["Pr(>F)"]][1]

#Pairwise comparisons NS vs. PS
X1 <- X %>% 
  ungroup() %>% 
  filter(Treatment != "ES")

Y1 <- X1 %>% select(6:9)

perm1 <- adonis(Y1 ~ X1$Treatment*X1$Time_observed, 
                strata = X1$PairID, 
                permutation = 9999, 
                method = "euclidean")

pairwise_p["PS_NS"] <- perm1[["aov.tab"]][["Pr(>F)"]][1]

# P-value correction for multiple tests
p.adjust(pairwise_p, method = "bonferroni")

## Plot Panel
img <- ggdraw() + draw_image("R-code/Figure4_HatchlingMorphology/EC_Larvae_FINAL.jpg")

panel <-  plot_grid(PCA.Plot, img, 
                    labels = c("a.", "b."),
                    #vjust= c(0.1, 1.5),
                    align = "hv",
                    axis = "tb",
                    nrow = 1) +
  theme(plot.margin = unit(c(1,0,0,0), "lines"))
panel

#ggsave(filename = file.path("Figure3_MorphologyPane.pdf"), height = 3.5, width = 8.5, units = "in", dpi = 300)
